@@ -5,7 +5,7 @@ import requests
 from requests import HTTPError
 
 RFC_RE = r"[A-ZÑ&]{3,4}[0-9]{2}[0-1][0-9][0-3][0-9][A-Z,0-9]?[A-Z,0-9]?[0-9,A-Z]?"
-DATE_FILTER_RE = r"^([rdmw]:((\d{2,4}-?){3}T(\d{2}:?){3}_?){1,2}|rr:(1_30|31_60|61_90|91\+|today|current_month|previous_month|current_week|previous_week)|all)$"
+DATE_FILTER_RE = r"^([rdmw]:((\d{2,4}-?){3}T(\d{2}:?){3}_?){1,2}|rr:(1_30|31_60|61_90|91\+|today|current_month|previous_month|current_week|previous_week)|all|null)$"
 
 
 class ListoAPIError(Exception):
