@@ -13,7 +13,7 @@ class Suppliers(ListoAPI):
             kwargs["q"] = kwargs.pop("rfc")
 
         for s in self.make_request(
-                method="GET", path="/suppliers/%s" % rfc_id,
+                method="GET", path="/counterparties/suppliers/%s" % rfc_id,
                 params=kwargs).json()["hits"]:
             yield s
 
